@@ -5,6 +5,7 @@ from procuret.instalment_link import InstalmentLinkOrderBy
 from procuret.data.order import Order
 from procuret.human.headline import HumanHeadline
 from procuret.ancillary.entity_headline import EntityHeadline
+from procuret.ancillary.sale_nomenclature import SaleNomenclature
 from procuret import errors
 from procuret.version import VERSION
 from procuret.term_rate.term_rate import TermRate
@@ -13,3 +14,7 @@ from procuret.integrate.xero import XeroOrganisation, XeroEntityMap
 from procuret.money.amount import Amount
 from procuret.money.currency import Currency, Constants as Currencies
 from procuret.data.codable import Codable, CodingDefinition
+from procuret.global_brand.brand import GlobalBrand
+from procuret.global_brand.selection import GlobalBrandSelection
+from procuret.payment_series.series import PaymentSeries
+from procuret.customer_payment.payment import CustomerPayment
