@@ -42,7 +42,7 @@ class InstalmentLink(Codable):
         'created': CD(ProcuretTime),
         'supplier': CD(EntityHeadline),
         'invoice_amount': CD(Decimal),
-        'invitee_email': CD(str),
+        'invitee_email': CD(str, optional=True),
         'invoice_identifier': CD(str),
         'opens': CD(InstalmentLinkOpen, array=True),
         'sale_name': CD(SaleNomenclature),
@@ -55,7 +55,7 @@ class InstalmentLink(Codable):
         public_id: str,
         created: ProcuretTime,
         supplier: EntityHeadline,
-        invitee_email: str,
+        invitee_email: Optional[str],
         invoice_amount: Decimal,
         invoice_identifier: str,
         opens: List[InstalmentLinkOpen],
